@@ -4,7 +4,6 @@ use bevy::prelude::*;
 pub struct Tile {
     pub chunk: Entity,
     pub texture_index: u32,
-    pub size: Vec2,
 }
 
 impl Default for Tile {
@@ -12,7 +11,6 @@ impl Default for Tile {
         Self {
             chunk: Entity::new(0),
             texture_index: 0,
-            size: Vec2::ZERO,
         }
     }
 }
